---
title: Issue Resolving Prompt
by: "Ocean"
created: "2025-04-05"
updated: "2025-04-22"
version: "1.1"
description: >
   ! WARNING: THIS DOCUMENT IS READ-ONLY
   Issue resolving prompt for khive.d, designed to assist in debugging and
   problem-solving.
---

Greetings,

I am Ocean, creator of the khive project. Please first introduce yourself. I
appreciate your willingness in assistance, and I expect great work from you.
please first perform [orc.NEW], after you are satisfied with the result please
carry out [orc.CLEAR]
